﻿import es
import os
import advertlib
import configobj

info = es.AddonInfo()
info.author = 'Brainsucker'
info.name = 'EasyAdverts'
info.esamname = 'easyadverts'
info.version = '1.0.0 rev2'
info.description = 'Erlaubt das einfache Configurieren und Erstellen von Adverts mit der advertlib'
info.url = 'http://addons.eventscripts.com/addons/view/%s' % info.esamname


addonpath, addonfile = os.path.split(__file__)

configfilepath = os.path.join(addonpath, 'advertconfig.ini')

cfg = configobj.ConfigObj(configfilepath)

if not os.path.isfile(configfilepath):
	
	cfg.initial_comments = ['Bitte die Struktur der Adverts bei allen gezeigten Beispielen beibehalten!', 'Hier werden die verschiedenen Arten und Texte der Adverts definiert.'] 
	
	cfg['advert1'] = {}
	cfg.comments['advert1'] = ['Der Name dieses Adverts kann beliebig gewählt werden.', 'Dadurch bestimmst du unter welchem "Namen" dein Advert identifiziert werden kann']
	
	cfg['advert1']['adv_text'] = 'Dies $colorist $colorein mehrfarbiger $colorText'
	cfg['advert1']['adv_colors'] = ['#lightgreen', '#default', '#green']
	cfg['advert1'].comments['adv_colors'] = ['Bei dem Adverttyp "chat" ist es möglich den Adverttext farbig zu gestalten.', 'Um Farben verwenden zu können, muss ab der stelle ab der die Nachricht eine andere Farbe erhalten soll "$color" (ohne die "") eingefügt werden.', 'Die jeweilige Farbe wird dann der reihe nach in der Variable "adv_colors" definiert.']
	
	cfg['advert1']['adv_enabled'] = True
	cfg['advert1'].comments['adv_enabled'] = ['Hier lassen sich die Adverts auch zeitweise ausschalten, ohne sie aus der Configurationsdatei löschen zu müssen.', 'Dazu einfach den Wert auf "False" (ohne die "") setzen.']
	
	cfg['advert1']['adv_type'] = 'chat'
	cfg['advert1'].comments['adv_type'] = ['Hier bestimmst du die Art des Adverts. Hierbei können folgende Werte eingesetzt werden:', 'chat', 'popup', 'center', 'hudhint', 'Jeder dieser Werte gibt das Advert an einer anderen Stelle auf dem Benutzerbildschirm aus.', 'Bitte beachte, dass bei den versch. Adverttypen teilweise auch verschiedene Werte benötigt werden bzw. configuriert werden können.', 'Daher wird empfohlen dich an diese Beispiele zu halten und deren Muster bei der configuration zu verwenden.']

	cfg['advert2'] = {}
	cfg.comments['chat_advert2'] = ['Dieser Name darf ebenfalls beliebig sein, sollte aber nur einmal vorhanden sein!']
	
	cfg['advert2']['adv_text'] = 'Ein einfarbiges Advert'
	cfg['advert2']['adv_enabled'] = True
	cfg['advert2']['adv_type'] = 'chat'
	
	
	cfg['advert3'] = {}
	cfg['advert3']['adv_text'] = 'Dieses Advert ist nicht aktiv!'
	cfg['advert3']['adv_enabled'] = False
	cfg['advert3']['adv_type'] = 'chat'
	
	
	cfg['advert4'] = {}
	cfg['advert4']['adv_text'] = 'Dies ist der Text eines Popup Adverts'
	cfg['advert4']['adv_enabled'] = True
	cfg['advert4']['adv_type'] = 'popup'
	cfg['advert4'].comments['adv_type'] = ['Dieser Text wird als Popup beim User angezeigt.']
	
	
	
	
	cfg['advert5'] = {}
	cfg['advert5']['adv_text'] = 'Dieser Text erscheint für 10 Sekunden'
	cfg['advert5']['adv_duration'] = 10
	cfg['advert5']['adv_enabled'] = True
	cfg['advert5']['adv_type'] = 'center'
	cfg['advert5'].comments['adv_type'] = ['Diese Adverts werden in der Mitte des Bildschirmes bei den Spielern angezeigt.']
	
	
	
	
	cfg['advert6'] = {}
	cfg['advert6']['adv_text'] = 'Dies ist ein Hudhint Advert.'
	cfg['advert6']['adv_enabled'] = True
	cfg['advert6']['adv_type'] = 'hudhint'
	cfg['advert6'].comments['adv_type'] = ['Diese Adverts erscheinen mittig am unteren Bildschirmrand des Spielers. Bitte nur für kurze Adverts benutzen.']


	cfg.write()
	

# Holds the Adverts, that have been registered by this Addon. That makes it easier to unregister them when the Addon is unloaded.
registered_adverts = []


def load():
	global adv
	adv = advertlib.ChatAdvert('easyadverts_advert', 'This Server is running $color%s $colorVersion: $color%s $colorby $color%s$color.' % (info.name, info.version, info.author))
	adv.colors = ['#lightgreen', '#default', '#green', '#default', '#green', '#default']
	adv.enabled = True
	
	es.ServerVar(info.name, info.version).makepublic()
	
	
	for advert_name in cfg:
		adv_type = 'chat' # Set a default type.
		if 'adv_type' in cfg[advert_name]:
			adv_type = cfg[advert_name]['adv_type']
		adv_type_lo = adv_type.lower()
		adv_text = cfg[advert_name]['adv_text']
		if adv_type_lo == 'chat':
			a = advertlib.ChatAdvert(advert_name, adv_text)
			if 'adv_colors' in cfg[advert_name]:
				a.colors = cfg[advert_name].as_list('adv_colors')
			
				
		elif adv_type_lo == 'popup':
			a = advertlib.PopupAdvert(advert_name, adv_text)
			
			
		elif adv_type_lo == 'center':
			a = advertlib.CenterAdvert(advert_name, adv_text)
			if 'adv_duration' in cfg[advert_name]:
				a.duration = cfg[advert_name].as_int('adv_duration')
				
		elif adv_type_lo == 'hudhint':
			a = advertlib.HudhintAdvert(advert_name, adv_text)
			
			
		else:
			es.dbgmsg(0, '[%s] Der Angegebene Adverttyp "%s" bei dem Advert "%s" ist nicht verfügbar.' % (adv_type, advert_name))
			continue
			
		if 'adv_enabled' in cfg[advert_name]:
			a.enabled = cfg[advert_name].as_bool('adv_enabled')
			
		registered_adverts.append(a)
	
	
def unload():
	global adv
	adv.unregister()
	
	for reg_adv in registered_adverts:
		reg_adv.unregister()